==> cloudt-boot-starter-auth-3.2.4.16-20230610.072919-1-sources.jar: com/elitescloud/boot/auth/client/config/support/RedisAuthenticationCache.java <==
package com.elitescloud.boot.auth.client.config.support;

import com.elitescloud.boot.auth.client.common.SecurityConstants;
import com.elitescloud.boot.auth.client.tool.RedisHelper;
import com.elitescloud.boot.exception.BusinessException;
import com.elitescloud.cloudt.security.entity.GeneralUserDetails;
import lombok.extern.log4j.Log4j2;
import org.springframework.lang.NonNull;

import java.time.Duration;

/**
 * redis身份认证缓存.
 *
 * @author Kaiser（wang shao）
 * @date 2022/7/2
 */
@Log4j2
public class RedisAuthenticationCache implements AuthenticationCache {

    private final RedisHelper redisHelper;

    public RedisAuthenticationCache(RedisHelper redisHelper) {
        this.redisHelper = redisHelper;
    }

    @Override
    public void setUserDetail(@NonNull String key, @NonNull GeneralUserDetails user, Duration timeToLive) {
        try {
            redisHelper.execute(redisUtils -> {
                String cacheKey = generateCacheKey(key);
                if (timeToLive != null) {
                    redisUtils.set(cacheKey, user, timeToLive.toSeconds());
                    return null;
                }

                redisUtils.set(cacheKey, user);
                return null;
            });
        } catch (Exception e) {
            throw new BusinessException("缓存用户详细信息失败", e);
        }
    }

    @Override
    public GeneralUserDetails getUserDetail(@NonNull String key) {
        try {
            return redisHelper.execute(redisUtils -> {
                String cacheKey = generateCacheKey(key);
                return (GeneralUserDetails) redisUtils.get(cacheKey);
            });
        } catch (Exception e) {
            throw new BusinessException("获取用户详细信息失败", e);
        }
    }

    @Override
    public void removeUserDetail(String key) {
        try {
            redisHelper.execute(redisUtils -> {
                String cacheKey = generateCacheKey(key);
                redisUtils.del(cacheKey);

                return null;
            });
        } catch (Exception e) {
            throw new BusinessException("删除用户详细信息失败", e);
        }
    }

    private String generateCacheKey(String cacheKey) {
        return SecurityConstants.CACHE_PREFIX_CURRENT_USER + cacheKey;
    }
}

==> cloudt-boot-starter-auth-3.2.5.33-20231129.094732-1-sources.jar: com/elitescloud/boot/auth/client/config/support/RedisAuthenticationCache.java <==
package com.elitescloud.boot.auth.client.config.support;

import com.elitescloud.boot.auth.client.common.SecurityConstants;
import com.elitescloud.boot.auth.client.tool.RedisHelper;
import com.elitescloud.boot.exception.BusinessException;
import com.elitescloud.cloudt.security.entity.GeneralUserDetails;
import lombok.extern.log4j.Log4j2;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.lang.NonNull;

import java.time.Duration;
import java.util.concurrent.TimeUnit;

/**
 * redis身份认证缓存.
 *
 * @author Kaiser（wang shao）
 * @date 2022/7/2
 */
@Log4j2
public class RedisAuthenticationCache implements AuthenticationCache {

    private final RedisHelper redisHelper;

    public RedisAuthenticationCache(RedisHelper redisHelper) {
        this.redisHelper = redisHelper;
    }

    @Override
    public void setUserDetail(@NonNull String key, @NonNull GeneralUserDetails user, Duration timeToLive) {
        try {
            redisHelper.execute(redisUtils -> {
                var cacheKey = this.generateCacheKey(key);
                if (timeToLive != null) {
                    redisUtils.set(cacheKey, user, timeToLive.toSeconds());
                    return null;
                }

                redisUtils.set(cacheKey, user);
                return null;
            });
        } catch (Exception e) {
            throw new BusinessException("缓存用户详细信息失败", e);
        }
    }

    @Override
    public GeneralUserDetails getUserDetail(@NonNull String key) {
        try {
            return redisHelper.execute(redisUtils -> {
                var cacheKey = this.generateCacheKey(key);
                return (GeneralUserDetails) redisUtils.get(cacheKey);
            });
        } catch (Exception e) {
            throw new BusinessException("获取用户详细信息失败", e);
        }
    }

    @Override
    public void removeUserDetail(@NonNull String key) {
        try {
            redisHelper.execute(redisUtils -> {
                var cacheKey = this.generateCacheKey(key);
                redisUtils.del(cacheKey);

                return null;
            });
        } catch (Exception e) {
            throw new BusinessException("删除用户详细信息失败", e);
        }
    }

    @Override
    public void expireAt(@NonNull String key, Duration ttl) {
        try {
            redisHelper.execute(redisUtils -> {
                var cacheKey = this.generateCacheKey(key);
                if (ttl == null) {
                    redisUtils.del(cacheKey);
                    return null;
                }

                redisUtils.expire(cacheKey, ttl.toSeconds(), TimeUnit.SECONDS);
                return null;
            });
        } catch (Exception e) {
            throw new BusinessException("设置用户过期时间失败", e);
        }
    }

    private String generateCacheKey(String cacheKey) {
        return SecurityConstants.CACHE_PREFIX_CURRENT_USER + cacheKey;
    }
}
